==> graphql-language-service-3.1.2.jar: META-INF/resources/webjars/graphql-language-service/3.1.2/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [3.1.2](https://github.com/graphql/graphiql/compare/graphql-language-service@3.1.1...graphql-language-service@3.1.2) (2021-01-07)

**Note:** Version bump only for package graphql-language-service

## [3.1.1](https://github.com/graphql/graphiql/compare/graphql-language-service@3.1.0...graphql-language-service@3.1.1) (2021-01-07)

**Note:** Version bump only for package graphql-language-service

# [3.1.0](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.6...graphql-language-service@3.1.0) (2021-01-07)

### Features

- implied or external fragments, for [#612](https://github.com/graphql/graphiql/issues/612) ([#1750](https://github.com/graphql/graphiql/issues/1750)) ([cfed265](https://github.com/graphql/graphiql/commit/cfed265e3cf31875b39ea517781a217fcdfcadc2))

## [3.0.6](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.5...graphql-language-service@3.0.6) (2021-01-03)

**Note:** Version bump only for package graphql-language-service

## [3.0.5](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.4...graphql-language-service@3.0.5) (2020-12-28)

**Note:** Version bump only for package graphql-language-service

## [3.0.4](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.3...graphql-language-service@3.0.4) (2020-12-08)

**Note:** Version bump only for package graphql-language-service

## [3.0.3](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.2...graphql-language-service@3.0.3) (2020-11-28)

**Note:** Version bump only for package graphql-language-service

## [3.0.2](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.2-alpha.3...graphql-language-service@3.0.2) (2020-09-18)

**Note:** Version bump only for package graphql-language-service

## [3.0.2-alpha.3](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.2-alpha.2...graphql-language-service@3.0.2-alpha.3) (2020-09-11)

**Note:** Version bump only for package graphql-language-service

## [3.0.2-alpha.2](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.2-alpha.1...graphql-language-service@3.0.2-alpha.2) (2020-08-22)

### Bug Fixes

- improve setSchema & schema loading, allow primitive schema ([#1648](https://github.com/graphql/graphiql/issues/1648)) ([975f29e](https://github.com/graphql/graphiql/commit/975f29ed6e21c7354c42ed778dfd1b52287f70c6))

## [3.0.2-alpha.1](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.2-alpha.0...graphql-language-service@3.0.2-alpha.1) (2020-08-12)

**Note:** Version bump only for package graphql-language-service

## [3.0.2-alpha.0](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.1...graphql-language-service@3.0.2-alpha.0) (2020-08-10)

**Note:** Version bump only for package graphql-language-service

## [3.0.1](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.0...graphql-language-service@3.0.1) (2020-08-06)

**Note:** Version bump only for package graphql-language-service

# [3.0.0](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.0-alpha.4...graphql-language-service@3.0.0) (2020-06-11)

### Features

- standalone monaco API ([#1575](https://github.com/graphql/graphiql/issues/1575)) ([954aa3d](https://github.com/graphql/graphiql/commit/954aa3d7159fd26bba9650824e0f668e417ca64f))

# [3.0.0-alpha.4](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.0-alpha.3...graphql-language-service@3.0.0-alpha.4) (2020-06-04)

**Note:** Version bump only for package graphql-language-service

# [3.0.0-alpha.3](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.0-alpha.2...graphql-language-service@3.0.0-alpha.3) (2020-06-04)

### Bug Fixes

- cleanup cache entry from lerna publish ([4a26218](https://github.com/graphql/graphiql/commit/4a2621808a1aea8b30d5d27b8d86a60bf2b44b01))

# [3.0.0-alpha.2](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.0-alpha.1...graphql-language-service@3.0.0-alpha.2) (2020-05-28)

**Note:** Version bump only for package graphql-language-service

# [3.0.0-alpha.1](https://github.com/graphql/graphiql/compare/graphql-language-service@2.4.0-alpha.8...graphql-language-service@3.0.0-alpha.1) (2020-05-19)

**Note:** Version bump only for package graphql-language-service

# 2.4.0-alpha.8 (2020-05-17)

### Features

- Monaco Mode - Phase 2 - Mode & Worker ([#1459](https://github.com/graphql/graphiql/issues/1459)) ([bc95fb4](https://github.com/graphql/graphiql/commit/bc95fb46459a4437ff9471ff43c98e1c5c50f51e))
- monaco-graphql docs, api, improvements ([#1521](https://github.com/graphql/graphiql/issues/1521)) ([c79158c](https://github.com/graphql/graphiql/commit/c79158c72e976ab286e7ec3fded7f3e2d24e50d0))
- new graphql-languageservice package ([#1485](https://github.com/graphql/graphiql/issues/1485)) ([6bb3ddd](https://github.com/graphql/graphiql/commit/6bb3dddf1f97db4bc193bb7fd9de1ada8d8c8ef9))

==> graphql-language-service-3.1.3.jar: META-INF/resources/webjars/graphql-language-service/3.1.3/CHANGELOG.md <==
# graphql-language-service

## 3.1.3

### Patch Changes

- [`6869ce77`](https://github.com/graphql/graphiql/commit/6869ce7767050787db5f1017abf82fa5a52fc97a) [#1816](https://github.com/graphql/graphiql/pull/1816) Thanks [@acao](https://github.com/acao)! - improve peer resolutions for graphql 14 & 15. `14.5.0` minimum is for built-in typescript types, and another method only available in `14.4.0`

## [3.1.2](https://github.com/graphql/graphiql/compare/graphql-language-service@3.1.1...graphql-language-service@3.1.2) (2021-01-07)

**Note:** Version bump only for package graphql-language-service

## [3.1.1](https://github.com/graphql/graphiql/compare/graphql-language-service@3.1.0...graphql-language-service@3.1.1) (2021-01-07)

**Note:** Version bump only for package graphql-language-service

## [3.1.0](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.6...graphql-language-service@3.1.0) (2021-01-07)

### Features

- implied or external fragments, for [#612](https://github.com/graphql/graphiql/issues/612) ([#1750](https://github.com/graphql/graphiql/issues/1750)) ([cfed265](https://github.com/graphql/graphiql/commit/cfed265e3cf31875b39ea517781a217fcdfcadc2))

## [3.0.6](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.5...graphql-language-service@3.0.6) (2021-01-03)

**Note:** Version bump only for package graphql-language-service

## [3.0.5](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.4...graphql-language-service@3.0.5) (2020-12-28)

**Note:** Version bump only for package graphql-language-service

## [3.0.4](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.3...graphql-language-service@3.0.4) (2020-12-08)

**Note:** Version bump only for package graphql-language-service

## [3.0.3](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.2...graphql-language-service@3.0.3) (2020-11-28)

**Note:** Version bump only for package graphql-language-service

## [3.0.2](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.2-alpha.3...graphql-language-service@3.0.2) (2020-09-18)

**Note:** Version bump only for package graphql-language-service

## [3.0.2-alpha.3](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.2-alpha.2...graphql-language-service@3.0.2-alpha.3) (2020-09-11)

**Note:** Version bump only for package graphql-language-service

## [3.0.2-alpha.2](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.2-alpha.1...graphql-language-service@3.0.2-alpha.2) (2020-08-22)

### Bug Fixes

- improve setSchema & schema loading, allow primitive schema ([#1648](https://github.com/graphql/graphiql/issues/1648)) ([975f29e](https://github.com/graphql/graphiql/commit/975f29ed6e21c7354c42ed778dfd1b52287f70c6))

## [3.0.2-alpha.1](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.2-alpha.0...graphql-language-service@3.0.2-alpha.1) (2020-08-12)

**Note:** Version bump only for package graphql-language-service

## [3.0.2-alpha.0](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.1...graphql-language-service@3.0.2-alpha.0) (2020-08-10)

**Note:** Version bump only for package graphql-language-service

## [3.0.1](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.0...graphql-language-service@3.0.1) (2020-08-06)

**Note:** Version bump only for package graphql-language-service

## [3.0.0](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.0-alpha.4...graphql-language-service@3.0.0) (2020-06-11)

### Features

- standalone monaco API ([#1575](https://github.com/graphql/graphiql/issues/1575)) ([954aa3d](https://github.com/graphql/graphiql/commit/954aa3d7159fd26bba9650824e0f668e417ca64f))

## [3.0.0-alpha.4](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.0-alpha.3...graphql-language-service@3.0.0-alpha.4) (2020-06-04)

**Note:** Version bump only for package graphql-language-service

## [3.0.0-alpha.3](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.0-alpha.2...graphql-language-service@3.0.0-alpha.3) (2020-06-04)

### Bug Fixes

- cleanup cache entry from lerna publish ([4a26218](https://github.com/graphql/graphiql/commit/4a2621808a1aea8b30d5d27b8d86a60bf2b44b01))

## [3.0.0-alpha.2](https://github.com/graphql/graphiql/compare/graphql-language-service@3.0.0-alpha.1...graphql-language-service@3.0.0-alpha.2) (2020-05-28)

**Note:** Version bump only for package graphql-language-service

## [3.0.0-alpha.1](https://github.com/graphql/graphiql/compare/graphql-language-service@2.4.0-alpha.8...graphql-language-service@3.0.0-alpha.1) (2020-05-19)

**Note:** Version bump only for package graphql-language-service

# 2.4.0-alpha.8 (2020-05-17)

### Features

- Monaco Mode - Phase 2 - Mode & Worker ([#1459](https://github.com/graphql/graphiql/issues/1459)) ([bc95fb4](https://github.com/graphql/graphiql/commit/bc95fb46459a4437ff9471ff43c98e1c5c50f51e))
- monaco-graphql docs, api, improvements ([#1521](https://github.com/graphql/graphiql/issues/1521)) ([c79158c](https://github.com/graphql/graphiql/commit/c79158c72e976ab286e7ec3fded7f3e2d24e50d0))
- new graphql-languageservice package ([#1485](https://github.com/graphql/graphiql/issues/1485)) ([6bb3ddd](https://github.com/graphql/graphiql/commit/6bb3dddf1f97db4bc193bb7fd9de1ada8d8c8ef9))
